==> haskell-data-bword-0.1.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-bword
version: 0.1.0.1
id: data-bword-0.1.0.1-BMFX5P1yMruBXXctfAidVq
key: data-bword-0.1.0.1-BMFX5P1yMruBXXctfAidVq
license: BSD3
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-bword
synopsis: Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.BinaryWord
abi: 2fb03aa355f7c3572b3a9e86ba72ab91
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/data-bword-0.1.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/data-bword-0.1.0.1
hs-libraries: HSdata-bword-0.1.0.1-BMFX5P1yMruBXXctfAidVq
depends:
    base-4.10.0.0 ghc-prim-0.5.1.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
haddock-interfaces: /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html: /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-bword-0.1.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-bword
version: 0.1.0.1
id: data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o
key: data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o
license: BSD3
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-bword
synopsis: Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.BinaryWord
abi: 489ccc47bb58cc09ab39cf342ed52ffa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-bword-0.1.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-bword-0.1.0.1
hs-libraries: HSdata-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html: /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
